"use server";

import { requestGetFetch } from "@/utils/fetch";
import { Session } from "next-auth";
import { getServerSession } from "next-auth";
import { nextauthOptions } from "../nextauth-options";
import { SearchParams } from "@/types/searchParams";

export async function getProjectModuleRequestList(searchParams?: SearchParams) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user.token;

    const paramsArray = searchParams && Object.entries(searchParams);
    const queryString = paramsArray && paramsArray.map(([key, value]) => `${key}=${value}`).join('&');
    const path = "v1/projects" + `${queryString ? `?${queryString}` : ''}`;

    const response = await requestGetFetch({
      path: path.toString(),
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });

    return response;
  } catch (error) {
    if (error) {
    }
    throw error;
  }
}

export async function createProjectModuleEntry(payload: any ) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    const path = "v1/projects/";
    const response = await requestGetFetch({
      path,
      options: {
        method: "POST",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
        body: JSON.stringify({ ...payload }),
      },
    });

    return response;
  } catch (error) {
    if (error) {

    }
    throw error;
  }
}

export async function editProjectModuleEntry(payload: { projectId: string; data: any }) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    const path = "v1/projects/" + payload?.projectId;
    const response = await requestGetFetch({
      path,
      options: {
        method: "PUT",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
        body: JSON.stringify(payload?.data || {}),
      },
    });

    return response;
  } catch (error) {
    if (error) {

    }
    throw error;
  }
}

export async function deleteProjectModuleEntry(id: number | string) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;
    const path = "v1/projects/" + id;
    const response = await requestGetFetch({
      path,
      options: {
        method: "DELETE",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: "no-store",
      },
    });

    return response;
  } catch (error) {
    if (error) {
    }
    throw error;
  }
}
